@@ -26,7 +26,6 @@
 #include "cipher-proto.h"
 #include "context.h"
 #include "mpi.h"
-#include "ec-context.h"
 
 const char *
 gcry_strerror (gcry_error_t err)
@@ -309,7 +308,7 @@ gcry_mpi_set_ui (gcry_mpi_t w, unsigned long u)
 }
 
 gcry_error_t
-gcry_mpi_get_ui (unsigned int *w, gcry_mpi_t u)
+gcry_mpi_get_ui (gcry_mpi_t w, unsigned long *u)
 {
   return gpg_error (_gcry_mpi_get_ui (w, u));
 }
@@ -571,47 +570,23 @@ gcry_mpi_ec_get_affine (gcry_mpi_t x, gcry_mpi_t y, gcry_mpi_point_t point,
 void
 gcry_mpi_ec_dup (gcry_mpi_point_t w, gcry_mpi_point_t u, gcry_ctx_t ctx)
 {
-  mpi_ec_t ec = _gcry_ctx_get_pointer (ctx, CONTEXT_TYPE_EC);
-
-  if (ec->model == MPI_EC_EDWARDS || ec->model == MPI_EC_MONTGOMERY)
-    {
-      mpi_point_resize (w, ec);
-      mpi_point_resize (u, ec);
-    }
-
-  _gcry_mpi_ec_dup_point (w, u, ec);
+  _gcry_mpi_ec_dup_point (w, u, _gcry_ctx_get_pointer (ctx, CONTEXT_TYPE_EC));
 }
 
 void
 gcry_mpi_ec_add (gcry_mpi_point_t w,
                  gcry_mpi_point_t u, gcry_mpi_point_t v, gcry_ctx_t ctx)
 {
-  mpi_ec_t ec = _gcry_ctx_get_pointer (ctx, CONTEXT_TYPE_EC);
-
-  if (ec->model == MPI_EC_EDWARDS || ec->model == MPI_EC_MONTGOMERY)
-    {
-      mpi_point_resize (w, ec);
-      mpi_point_resize (u, ec);
-      mpi_point_resize (v, ec);
-    }
-
-  _gcry_mpi_ec_add_points (w, u, v, ec);
+  _gcry_mpi_ec_add_points (w, u, v,
+                           _gcry_ctx_get_pointer (ctx, CONTEXT_TYPE_EC));
 }
 
 void
 gcry_mpi_ec_sub (gcry_mpi_point_t w,
                  gcry_mpi_point_t u, gcry_mpi_point_t v, gcry_ctx_t ctx)
 {
-  mpi_ec_t ec = _gcry_ctx_get_pointer (ctx, CONTEXT_TYPE_EC);
-
-  if (ec->model == MPI_EC_EDWARDS || ec->model == MPI_EC_MONTGOMERY)
-    {
-      mpi_point_resize (w, ec);
-      mpi_point_resize (u, ec);
-      mpi_point_resize (v, ec);
-    }
-
-  _gcry_mpi_ec_sub_points (w, u, v, ec);
+  _gcry_mpi_ec_sub_points (w, u, v,
+                           _gcry_ctx_get_pointer (ctx, CONTEXT_TYPE_EC));
 }
 
 void
@@ -736,7 +711,7 @@ gcry_cipher_open (gcry_cipher_hd_t *handle,
       *handle = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
+
   return gpg_error (_gcry_cipher_open (handle, algo, mode, flags));
 }
 
@@ -751,7 +726,7 @@ gcry_cipher_setkey (gcry_cipher_hd_t hd, const void *key, size_t keylen)
 {
   if (!fips_is_operational ())
     return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
+
   return gcry_error (_gcry_cipher_setkey (hd, key, keylen));
 }
 
@@ -773,22 +748,6 @@ gcry_cipher_setctr (gcry_cipher_hd_t hd, const void *ctr, size_t ctrlen)
   return gcry_error (_gcry_cipher_setctr (hd, ctr, ctrlen));
 }
 
-gcry_error_t
-gcry_cipher_setup_geniv (gcry_cipher_hd_t hd, int method,
-                         const void *fixed_iv, size_t fixed_iv_len,
-                         const void *dyn_iv, size_t dyn_iv_len)
-{
-  return gcry_error (_gcry_cipher_setup_geniv (hd, method,
-                                               fixed_iv, fixed_iv_len,
-                                               dyn_iv, dyn_iv_len));
-}
-
-gcry_error_t
-gcry_cipher_geniv (gcry_cipher_hd_t hd, void *iv, size_t iv_len)
-{
-  return gcry_error (_gcry_cipher_geniv (hd, iv, iv_len));
-}
-
 gcry_error_t
 gcry_cipher_authenticate (gcry_cipher_hd_t hd, const void *abuf, size_t abuflen)
 {
@@ -939,14 +898,14 @@ gcry_mac_get_algo_keylen (int algo)
 
 gcry_error_t
 gcry_mac_open (gcry_mac_hd_t *handle, int algo, unsigned int flags,
-               gcry_ctx_t ctx)
+	       gcry_ctx_t ctx)
 {
   if (!fips_is_operational ())
     {
       *handle = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
+
   return gpg_error (_gcry_mac_open (handle, algo, flags, ctx));
 }
 
@@ -962,10 +921,6 @@ gcry_mac_setkey (gcry_mac_hd_t hd, const void *key, size_t keylen)
   if (!fips_is_operational ())
     return gpg_error (fips_not_operational ());
 
-  fips_service_indicator_init ();
-  if (fips_mode () && keylen < 14)
-    fips_service_indicator_mark_non_compliant ();
-
   return gpg_error (_gcry_mac_setkey (hd, key, keylen));
 }
 
@@ -1022,7 +977,6 @@ gcry_pk_encrypt (gcry_sexp_t *result, gcry_sexp_t data, gcry_sexp_t pkey)
       *result = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
   return gpg_error (_gcry_pk_encrypt (result, data, pkey));
 }
 
@@ -1034,7 +988,6 @@ gcry_pk_decrypt (gcry_sexp_t *result, gcry_sexp_t data, gcry_sexp_t skey)
       *result = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
   return gpg_error (_gcry_pk_decrypt (result, data, skey));
 }
 
@@ -1046,66 +999,22 @@ gcry_pk_sign (gcry_sexp_t *result, gcry_sexp_t data, gcry_sexp_t skey)
       *result = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
   return gpg_error (_gcry_pk_sign (result, data, skey));
 }
 
-gcry_error_t
-gcry_pk_hash_sign (gcry_sexp_t *result, const char *data_tmpl, gcry_sexp_t skey,
-                   gcry_md_hd_t hd, gcry_ctx_t ctx)
-{
-  if (!fips_is_operational ())
-    {
-      *result = NULL;
-      return gpg_error (fips_not_operational ());
-    }
-  fips_service_indicator_init ();
-  return gpg_error (_gcry_pk_sign_md (result, data_tmpl, hd, skey, ctx));
-}
-
 gcry_error_t
 gcry_pk_verify (gcry_sexp_t sigval, gcry_sexp_t data, gcry_sexp_t pkey)
 {
   if (!fips_is_operational ())
     return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
   return gpg_error (_gcry_pk_verify (sigval, data, pkey));
 }
 
-gcry_error_t
-gcry_pk_hash_verify (gcry_sexp_t sigval, const char *data_tmpl, gcry_sexp_t pkey,
-                     gcry_md_hd_t hd, gcry_ctx_t ctx)
-{
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
-  return gpg_error (_gcry_pk_verify_md (sigval, data_tmpl, hd, pkey, ctx));
-}
-
-gcry_error_t
-gcry_pk_random_override_new (gcry_ctx_t *r_ctx, const unsigned char *p, size_t len)
-{
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
-
-  if (fips_mode ())
-    {
-      if (fips_check_rejection (GCRY_FIPS_FLAG_REJECT_PK_FLAGS))
-        return gpg_error (GPG_ERR_INV_OP);
-      else
-        fips_service_indicator_mark_non_compliant ();
-    }
-
-  return gpg_error (_gcry_pk_single_data_push (r_ctx, p, len));
-}
-
 gcry_error_t
 gcry_pk_testkey (gcry_sexp_t key)
 {
   if (!fips_is_operational ())
     return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
   return gpg_error (_gcry_pk_testkey (key));
 }
 
@@ -1117,7 +1026,6 @@ gcry_pk_genkey (gcry_sexp_t *r_key, gcry_sexp_t s_parms)
       *r_key = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
   return gpg_error (_gcry_pk_genkey (r_key, s_parms));
 }
 
@@ -1156,7 +1064,7 @@ gcry_pk_get_nbits (gcry_sexp_t key)
       (void)fips_not_operational ();
       return 0;
     }
-  fips_service_indicator_init ();
+
   return _gcry_pk_get_nbits (key);
 }
 
@@ -1179,7 +1087,6 @@ gcry_pk_get_curve (gcry_sexp_t key, int iterator, unsigned int *r_nbits)
       (void)fips_not_operational ();
       return NULL;
     }
-  fips_service_indicator_init ();
   return _gcry_pk_get_curve (key, iterator, r_nbits);
 }
 
@@ -1205,19 +1112,6 @@ gcry_pubkey_get_sexp (gcry_sexp_t *r_sexp, int mode, gcry_ctx_t ctx)
   return gpg_error (_gcry_pubkey_get_sexp (r_sexp, mode, ctx));
 }
 
-unsigned int
-gcry_ecc_get_algo_keylen (int curveid)
-{
-  return _gcry_ecc_get_algo_keylen (curveid);
-}
-
-gpg_error_t
-gcry_ecc_mul_point (int curveid, unsigned char *result,
-                    const unsigned char *scalar, const unsigned char *point)
-{
-  return gpg_error (_gcry_ecc_mul_point (curveid, result, scalar, point));
-}
-
 gcry_error_t
 gcry_md_open (gcry_md_hd_t *h, int algo, unsigned int flags)
 {
@@ -1226,7 +1120,7 @@ gcry_md_open (gcry_md_hd_t *h, int algo, unsigned int flags)
       *h = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
+
   return gpg_error (_gcry_md_open (h, algo, flags));
 }
 
@@ -1241,7 +1135,6 @@ gcry_md_enable (gcry_md_hd_t hd, int algo)
 {
   if (!fips_is_operational ())
     return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
   return gpg_error (_gcry_md_enable (hd, algo));
 }
 
@@ -1253,7 +1146,6 @@ gcry_md_copy (gcry_md_hd_t *bhd, gcry_md_hd_t ahd)
       *bhd = NULL;
       return gpg_error (fips_not_operational ());
     }
-  fips_service_indicator_init ();
   return gpg_error (_gcry_md_copy (bhd, ahd));
 }
 
@@ -1291,9 +1183,7 @@ gcry_md_read (gcry_md_hd_t hd, int algo)
 gcry_error_t
 gcry_md_extract (gcry_md_hd_t hd, int algo, void *buffer, size_t length)
 {
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  return gpg_error (_gcry_md_extract (hd, algo, buffer, length));
+  return gpg_error (_gcry_md_extract(hd, algo, buffer, length));
 }
 
 void
@@ -1305,7 +1195,6 @@ gcry_md_hash_buffer (int algo, void *digest,
       (void)fips_not_operational ();
       fips_signal_error ("called in non-operational state");
     }
-  fips_service_indicator_init ();
   _gcry_md_hash_buffer (algo, digest, buffer, length);
 }
 
@@ -1318,25 +1207,9 @@ gcry_md_hash_buffers (int algo, unsigned int flags, void *digest,
       (void)fips_not_operational ();
       fips_signal_error ("called in non-operational state");
     }
-  fips_service_indicator_init ();
   return gpg_error (_gcry_md_hash_buffers (algo, flags, digest, iov, iovcnt));
 }
 
-gpg_error_t
-gcry_md_hash_buffers_ext (int algo, unsigned int flags, void *digest,
-                          int digestlen, const gcry_buffer_t *iov,
-                          int iovcnt)
-{
-  if (!fips_is_operational ())
-    {
-      (void)fips_not_operational ();
-      fips_signal_error ("called in non-operational state");
-    }
-  fips_service_indicator_init ();
-  return gpg_error (_gcry_md_hash_buffers_extract (algo, flags, digest,
-                                                   digestlen, iov, iovcnt));
-}
-
 int
 gcry_md_get_algo (gcry_md_hd_t hd)
 {
@@ -1385,9 +1258,6 @@ gcry_md_info (gcry_md_hd_t h, int what, void *buffer, size_t *nbytes)
 gcry_error_t
 gcry_md_algo_info (int algo, int what, void *buffer, size_t *nbytes)
 {
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
   return gpg_error (_gcry_md_algo_info (algo, what, buffer, nbytes));
 }
 
@@ -1408,11 +1278,6 @@ gcry_md_setkey (gcry_md_hd_t hd, const void *key, size_t keylen)
 {
   if (!fips_is_operational ())
     return gpg_error (fips_not_operational ());
-
-  fips_service_indicator_init ();
-  if (fips_mode () && keylen < 14)
-    fips_service_indicator_mark_non_compliant ();
-
   return gpg_error (_gcry_md_setkey (hd, key, keylen));
 }
 
@@ -1429,90 +1294,11 @@ gcry_kdf_derive (const void *passphrase, size_t passphraselen,
                  unsigned long iterations,
                  size_t keysize, void *keybuffer)
 {
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  fips_service_indicator_init ();
   return gpg_error (_gcry_kdf_derive (passphrase, passphraselen, algo, hashalgo,
                                       salt, saltlen, iterations,
                                       keysize, keybuffer));
 }
 
-gpg_error_t
-gcry_kdf_open (gcry_kdf_hd_t *hd, int algo, int subalgo,
-               const unsigned long *param, unsigned int paramlen,
-               const void *passphrase, size_t passphraselen,
-               const void *salt, size_t saltlen,
-               const void *key, size_t keylen,
-               const void *ad, size_t adlen)
-{
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  return gpg_error (_gcry_kdf_open (hd, algo, subalgo, param, paramlen,
-                                    passphrase, passphraselen, salt, saltlen,
-                                    key, keylen, ad, adlen));
-}
-
-gcry_error_t
-gcry_kdf_compute (gcry_kdf_hd_t h, const struct gcry_kdf_thread_ops *ops)
-{
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  return gpg_error (_gcry_kdf_compute (h, ops));
-}
-
-gcry_error_t
-gcry_kdf_final (gcry_kdf_hd_t h, size_t resultlen, void *result)
-{
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
-  return gpg_error (_gcry_kdf_final (h, resultlen, result));
-}
-
-void
-gcry_kdf_close (gcry_kdf_hd_t h)
-{
-  _gcry_kdf_close (h);
-}
-
-gcry_error_t
-gcry_kem_keypair (int algo,
-                  void *pubkey, size_t pubkey_len,
-                  void *seckey, size_t seckey_len)
-{
-  return gpg_error (_gcry_kem_genkey (algo,
-                                      pubkey, pubkey_len,
-                                      seckey, seckey_len,
-                                      NULL, 0));
-}
-
-gcry_error_t
-gcry_kem_encap (int algo,
-                const void *pubkey, size_t pubkey_len,
-                void *ciphertext, size_t ciphertext_len,
-                void *shared, size_t shared_len,
-                const void *optional, size_t optional_len)
-{
-  return gpg_error (_gcry_kem_encap (algo,
-                                     pubkey, pubkey_len,
-                                     ciphertext, ciphertext_len,
-                                     shared, shared_len,
-                                     optional, optional_len));
-}
-
-gcry_error_t
-gcry_kem_decap (int algo,
-                const void *seckey, size_t seckey_len,
-                const void *ciphertext, size_t ciphertext_len,
-                void *shared, size_t shared_len,
-                const void *optional, size_t optional_len)
-{
-  return gpg_error (_gcry_kem_decap (algo,
-                                     seckey, seckey_len,
-                                     ciphertext, ciphertext_len,
-                                     shared, shared_len,
-                                     optional, optional_len));
-}
-
 void
 gcry_randomize (void *buffer, size_t length, enum gcry_random_level level)
 {
@@ -1563,13 +1349,6 @@ void
 gcry_mpi_randomize (gcry_mpi_t w,
                     unsigned int nbits, enum gcry_random_level level)
 {
-  if (!fips_is_operational ())
-    {
-      (void)fips_not_operational ();
-      fips_signal_fatal_error ("called in non-operational state");
-      fips_noreturn ();
-    }
-
   _gcry_mpi_randomize (w, nbits, level);
 }
 
@@ -1595,8 +1374,6 @@ gcry_prime_generate (gcry_mpi_t *prime,
                      gcry_random_level_t random_level,
                      unsigned int flags)
 {
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
   return gpg_error (_gcry_prime_generate (prime, prime_bits, factor_bits,
                                           factors, cb_func, cb_arg,
                                           random_level, flags));
@@ -1607,8 +1384,6 @@ gcry_prime_group_generator (gcry_mpi_t *r_g,
                             gcry_mpi_t prime, gcry_mpi_t *factors,
                             gcry_mpi_t start_g)
 {
-  if (!fips_is_operational ())
-    return gpg_error (fips_not_operational ());
   return gpg_error (_gcry_prime_group_generator (r_g, prime, factors, start_g));
 }
 
